@@ -76,15 +76,11 @@ class Document(
     swap_base = True
 
 
-class DynamicDocument(
-    django_meta(mtc.TopLevelDocumentMetaclass, DjangoFlavor, me.DynamicDocument)
-):
+class DynamicDocument(django_meta(mtc.TopLevelDocumentMetaclass, DjangoFlavor, me.DynamicDocument)):
     swap_base = True
 
 
-class EmbeddedDocument(
-    django_meta(mtc.DocumentMetaclass, DjangoFlavor, me.EmbeddedDocument)
-):
+class EmbeddedDocument(django_meta(mtc.DocumentMetaclass, DjangoFlavor, me.EmbeddedDocument)):
     swap_base = True
 
 
