@@ -8,6 +8,7 @@ from django_mongoengine.forms.widgets import Dictionary, EmbeddedFieldWidget
 class ReferenceField(forms.ModelChoiceField):
     pass
 
+
 class DocumentMultipleChoiceField(forms.ModelMultipleChoiceField):
     pass
 
@@ -21,16 +22,16 @@ class DictField(forms.Field):
         'length': _(u'Ensure the keys length is less than or equal to %s.'),
         'invalid_key': _(u'Ensure the keys are not : %s.'),
         'illegal': _(u'Ensure the keys does not contain any illegal character : %s.'),
-        'depth': _(u'Ensure the dictionary depth is less than or equal to %s.')
+        'depth': _(u'Ensure the dictionary depth is less than or equal to %s.'),
     }
 
-    #Mongo reserved keywords
+    # Mongo reserved keywords
     invalid_keys = ['err', 'errmsg']
-    #Mongo prohibit . in keys
+    # Mongo prohibit . in keys
     illegal_characters = ['.']
-    #limit key length for efficiency
+    # limit key length for efficiency
     key_limit = 200
-    #limit depth for dictionaries
+    # limit depth for dictionaries
     max_depth = None
 
     def __init__(self, max_depth=None, flags=None, sub_attrs=None, attrs=None, *args, **kwargs):
@@ -39,18 +40,20 @@ class DictField(forms.Field):
         else:
             kwargs['error_messages'] = self.error_messages
 
-        self.max_depth = (max_depth if max_depth and max_depth >= 0 else None)
+        self.max_depth = max_depth if max_depth and max_depth >= 0 else None
 
         if 'widget' not in kwargs.keys():
             schema = None
-            #Here it needs to be clearer, because this is only useful when creating an object,
-            #if no default value is provided, default is callable
+            # Here it needs to be clearer, because this is only useful when creating an object,
+            # if no default value is provided, default is callable
             if 'initial' in kwargs and not callable(kwargs['initial']):
                 if isinstance(kwargs['initial'], dict):
                     schema = kwargs['initial']
 
-            #here if other parameters are passed, like max_depth and flags, then we hand them to the dict
-            kwargs['widget'] = Dictionary(max_depth=max_depth, flags=flags, schema=schema, sub_attrs=sub_attrs)
+            # here if other parameters are passed, like max_depth and flags, then we hand them to the dict
+            kwargs['widget'] = Dictionary(
+                max_depth=max_depth, flags=flags, schema=schema, sub_attrs=sub_attrs
+            )
 
         super(DictField, self).__init__(*args, **kwargs)
 
@@ -73,7 +76,7 @@ class DictField(forms.Field):
         """
         d = {}
         for k in a_list:
-            if (isinstance(k, list)):
+            if isinstance(k, list):
                 if isinstance(k[1], list) and k[0]:
                     d.update({k[0]: self.get_dict(k[1])})
                 elif k[0]:
@@ -81,7 +84,7 @@ class DictField(forms.Field):
         return d
 
     def validate(self, value, depth=0):
-        #we should not use the super.validate method
+        # we should not use the super.validate method
         if self.max_depth is not None and depth > self.max_depth:
             raise ValidationError(self.error_messages['depth'] % self.max_depth)
         for k, v in value.items():
@@ -96,6 +99,7 @@ class DictField(forms.Field):
             if isinstance(v, dict):
                 self.validate(v, depth + 1)
 
+
 class EmbeddedDocumentField(forms.MultiValueField):
     def __init__(self, form, *args, **kwargs):
         self.form = form()
@@ -103,13 +107,16 @@ class EmbeddedDocumentField(forms.MultiValueField):
         kwargs['widget'] = EmbeddedFieldWidget(self.form.fields)
         kwargs['initial'] = [f.initial for f in self.form.fields.values()]
         kwargs['require_all_fields'] = False
-        super(EmbeddedDocumentField, self).__init__(fields=tuple([f for f in self.form.fields.values()]), *args, **kwargs)
+        super(EmbeddedDocumentField, self).__init__(
+            fields=tuple([f for f in self.form.fields.values()]), *args, **kwargs
+        )
 
     def bound_data(self, data, initial):
         return data
 
     def prepare_value(self, value):
         return value
+
     def compress(self, data_list):
         data = {}
         if data_list:
@@ -124,5 +131,5 @@ class EmbeddedDocumentField(forms.MultiValueField):
 
     def to_python(self, value):
         obj = self.form._meta.model()
-        [ obj.__setattr__(k, value[k]) for k in value.keys() ]
+        [obj.__setattr__(k, value[k]) for k in value.keys()]
         return obj
