@@ -1,13 +1,15 @@
 from __future__ import absolute_import
 
-from .list import ListView
 from .detail import DetailView
+from .edit import CreateView, DeleteView, UpdateView
 from .embedded import EmbeddedDetailView
-from .edit import CreateView, UpdateView, DeleteView
+from .list import ListView
 
 __all__ = [
     "ListView",
     "DetailView",
     "EmbeddedDetailView",
-    "CreateView", "UpdateView", "DeleteView",
+    "CreateView",
+    "UpdateView",
+    "DeleteView",
 ]
