@@ -1,5 +1,7 @@
 from django.db import models
-from django_mongoengine import fields, Document
+
+from django_mongoengine import Document, fields
+
 
 class MongoDoc(Document):
     intfield = fields.IntField()
